@@ -9,5 +9,4 @@ class LabelQuerier(Querier):
     def query_points(self, idx1, idx2):
         return self.labels[idx1] == self.labels[idx2]
 
-    def update_clustering(self, clustering):
-        return
+
